unit test;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, StdCtrls, ExtCtrls, Buttons, Menus, nsShareLock;

type
  TfrmTester = class(TForm)
    lblTryNumber: TLabel;
    lblTryOut: TLabel;
    bvlSpacer: TBevel;
    lblDaysLeft: TLabel;
    lblDaysLeft_Out: TLabel;
    lblExpirationDate: TLabel;
    lblEventsFired: TLabel;
    lbStatus: TListBox;
    lblTrialLength: TLabel;
    lblGracePeriod: TLabel;
    lblExpireDate_Out: TLabel;
    lblTrialLength_Out: TLabel;
    lblGracePeriod_Out: TLabel;
    lblGraceExpire_Out: TLabel;
    lblGraceExpiration: TLabel;
    sbtnStatus: TSpeedButton;
    mnuMain: TMainMenu;
    mnuMain_File: TMenuItem;
    mnuMain_File_Exit: TMenuItem;
    mnuMain_Help: TMenuItem;
    mnuMain_Help_About: TMenuItem;
    mnuMain_Help_Register: TMenuItem;
    ShareLock: TnsShareLock;
    lblProtectionType: TLabel;
    lblProtectionType_Out: TLabel;
    lblProductName: TLabel;
    lblProductName_Out: TLabel;
    procedure ShareLockClockMovedBack(Sender: TObject);
    procedure DoStatus;
    procedure ShareLockExceededTries(Sender: TObject);
    procedure ShareLockUnlocked(Sender: TObject);
    procedure ShareLockRegistered(Sender: TObject);
    procedure ShareLockRegistryModified(Sender: TObject);
    procedure ShareLockInitialRun(Sender: TObject);
    procedure ShareLockInvalidUnlockCodeEntered(Sender: TObject);
    procedure ShareLockTrialExpired(Sender: TObject);
    procedure ShareLockWithinGracePeriod(Sender: TObject);
    procedure ShareLockWithinTrialPeriod(Sender: TObject);
    procedure ShareLockCannotOpenRegistry(Sender: TObject);
    procedure ShareLockExtended(ExtensionLength: Integer);
    procedure ShareLockTriedToExtendAgain(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure sbtnStatusClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure GiveOneChanceToRegister;
    procedure mnuMain_Help_AboutClick(Sender: TObject);
    procedure mnuMain_Help_RegisterClick(Sender: TObject);
    procedure mnuMain_File_ExitClick(Sender: TObject);
  private

  public
    fRegistered: Boolean;
  end;

var
  frmTester: TfrmTester;

implementation

uses Unlock, Help;

{$R *.DFM}

procedure TfrmTester.FormShow(Sender: TObject);
begin
  lbStatus.Items.Clear;
  ShareLock.CheckProtection;
  DoStatus;
end;

procedure TfrmTester.sbtnStatusClick(Sender: TObject);
begin
  if sbtnStatus.Down then
    begin
      Height := 395;
      sbtnStatus.Caption := 'Status <<';
    end
  else
    begin
      Height := 82;
     sbtnStatus.Caption := 'Status >>';
    end;
end;

procedure TfrmTester.FormCreate(Sender: TObject);
begin
  Height := 82;
  fRegistered := False;
end;

procedure TfrmTester.DoStatus;
begin
  lblTryOut.Caption := IntToStr(ShareLock.TryNumber);
  lblProductName_Out.Caption := ShareLock.ProductName;

  case ShareLock.Protection of
    ptRunCount:
      begin
        lblProtectionType_Out.Caption := 'Run Count';
        if (ShareLock.DaysLeft <= 0) and (ShareLock.GracePeriod > 0) then lblDaysLeft_Out.Caption := IntToStr( abs(ShareLock.GracePeriod + ShareLock.DaysLeft))
        else lblDaysLeft_Out.Caption := IntToStr(ShareLock.DaysLeft);
        lblExpireDate_Out.Caption := 'N/A';
        lblGraceExpire_Out.Caption := 'N/A';
        lblDaysLeft.Caption := 'Runs Left';
        lblTrialLength_Out.Caption := inttostr(ShareLock.TrialLength);
        lblGracePeriod_Out.Caption := inttostr(ShareLock.GracePeriod);
      end;
    ptSpecificDate, ptNumberDays:
      begin
        case ShareLock.Protection of
          ptSpecificDate: lblProtectionType_Out.Caption := 'Specific Date';
          ptNumberDays: lblProtectionType_Out.Caption := 'Number Days';
        end;
        lblDaysLeft_Out.Caption := IntToStr(ShareLock.DaysLeft);
        lblDaysLeft.Caption := 'Days Left';
        lblExpireDate_Out.Caption := FormatDateTime('ddddd', ShareLock.ExpirationDate);
        lblGraceExpire_Out.Caption := FormatDateTime('ddddd', ShareLock.ExpirationDate + ShareLock.GracePeriod);
        lblTrialLength_Out.Caption := inttostr(ShareLock.TrialLength);
        lblGracePeriod_Out.Caption := inttostr(ShareLock.GracePeriod);
      end;
    ptNoExpire:
      begin
        lblProtectionType_Out.Caption := 'No Expire';
        lblExpireDate_Out.Caption := 'N/A';
        lblGraceExpire_Out.Caption := 'N/A';
        lblTrialLength_Out.Caption := 'N/A';
        lblGracePeriod_Out.Caption := 'N/A';
        lblDaysLeft_Out.Caption := 'N/A';
      end;
  end;
end;

// TnsShareLock has discovered that the user has set the clock back.

procedure TfrmTester.ShareLockClockMovedBack(Sender: TObject);
begin
  lbStatus.Items.Add('Event: On Clock moved backward');
  MessageDlg('The system clock has been moved back. Please reset system clock to correct time before re-running application.', mtError, [mbOk], 0);
  Application.Terminate;
end;

// The user has tried entering a bad unlock code too many times

procedure TfrmTester.ShareLockExceededTries(Sender: TObject);
begin
  lbStatus.Items.Add('Event: OnExceededTries');
  MessageDlg('Please obtain a correct unlock code. Ending application.', mtInformation, [mbOk], 0);
  Application.Terminate;
end;

// The user has unlocked the software - this i only fired the one time it is unlocked.

procedure TfrmTester.ShareLockUnlocked(Sender: TObject);
begin
  lbStatus.Items.Add('Event: OnUnlocked');
  MessageDlg('Thank you for purchasing ' + ShareLock.ProductName + '!', mtInformation, [mbOk], 0);
  fRegistered := True;
end;

// This is fired each time the application is run AFTER it has been unlocked.

procedure TfrmTester.ShareLockRegistered(Sender: TObject);
begin
  lbStatus.Items.Add('Event: On registered');
  fRegistered := True;
end;

// TShareLock has noticed that either an entry has been modified, or else a key has been deleted

procedure TfrmTester.ShareLockRegistryModified(Sender: TObject);
begin
  lbStatus.Items.Add('Event: On registry modified');
  MessageDlg('The trial period has ended. Please register this software!', mtInformation, [mbOk], 0);
  GiveOneChanceToRegister;
end;

// This is the first time the application has been run

procedure TfrmTester.ShareLockInitialRun(Sender: TObject);
begin
  lbStatus.Items.Add('Event: On initial run');
  MessageDlg('Thank you for trying ' + ShareLock.ProductName + ' - please register it.', mtInformation, [mbOk], 0);
end;

// The user entered a bad unlock code

procedure TfrmTester.ShareLockInvalidUnlockCodeEntered(Sender: TObject);
begin
  lbStatus.Items.Add('Event: On Invalid Unlock Code');
  if ((ShareLock.Tries - ShareLock.TryNumber) - 1) > 0 then
    MessageDlg('You have entered an invalid unlock code.' + #10 + 'Please try again - you have ' + inttostr((ShareLock.Tries - ShareLock.TryNumber) - 1) + ' more tries remaining.', mtError, [mbOk], 0)
  else
    MessageDlg('You have entered an invalid unlock code.', mtError, [mbOk], 0)
end;

// The trial period has ended

procedure TfrmTester.ShareLockTrialExpired(Sender: TObject);
begin
  lbStatus.Items.Add('Event: On Expired');
  MessageDlg('The trial period can ended. Please register this software!', mtInformation, [mbOk], 0);
  GiveOneChanceToRegister;
end;

// This is the normal event fired when the application is within the grace period.

procedure TfrmTester.ShareLockWithinGracePeriod(Sender: TObject);
begin
  lbStatus.Items.Add('Event: Within grace period');
  if ShareLock.Protection = ptRunCount then
    MessageDlg('You are within a ' + inttostr(ShareLock.Graceperiod) + ' run grace period. Please register this program soon. It will completely expire in ' +
       IntToStr( abs(ShareLock.GracePeriod + ShareLock.DaysLeft)    ) + ' more runs', mtInformation, [mbOk], 0)
  else
    MessageDlg('You are within a ' + inttostr(ShareLock.Graceperiod) + ' day grace period. Please register this program soon. It will completely expire on ' +
     FormatDateTime('ddddd', ShareLock.ExpirationDate + ShareLock.GracePeriod), mtInformation, [mbOk], 0)
end;

// This is the normal event fired when the application is within the trial period

procedure TfrmTester.ShareLockWithinTrialPeriod(Sender: TObject);
begin
  lbStatus.Items.Add('Event: Within Trial period');

  if ShareLock.Protection = ptNoExpire then MessageDlg('Please register soon!', mtInformation, [mbOk], 0);

  if ShareLock.Protection = ptRunCount then
    begin
      if ShareLock.DaysLeft = 1 then
        MessageDlg('There is 1 run left in the trial', mtInformation, [mbOk], 0)
      else
        MessageDlg('There are ' + inttostr(ShareLock.DaysLeft) + ' runs left in the trial', mtInformation, [mbOk], 0);
    end;

  if (ShareLock.Protection = ptNumberDays) or (ShareLock.Protection = ptSpecificDate) then
    begin
      if ShareLock.DaysLeft = 1 then
        MessageDlg('There is 1 day left in the trial. The trial will end on ' + FormatDateTime('ddddd', ShareLock.ExpirationDate) + '.', mtInformation, [mbOk], 0)
      else
        MessageDlg('There are ' + inttostr(ShareLock.DaysLeft) + ' days left in the trial. The trial will end on ' + FormatDateTime('ddddd', ShareLock.ExpirationDate) + '.', mtInformation, [mbOk], 0);
    end;
end;

// TShareLock cannot open the registry.

procedure TfrmTester.ShareLockCannotOpenRegistry(Sender: TObject);
begin
  lbStatus.Items.Add('Event: On Cannot open registry');
  MessageDlg(ShareLock.ProductName + ' cannot access the system registry in order to write configuration information.' + #10 + 'This can be caused by not having write access over a network, etc. The application will now close.', mtError, [mbOk], 0);
  Application.Terminate;
end;

// The user, using an unlock code has extended the trial time

procedure TfrmTester.ShareLockExtended(ExtensionLength: Integer);
begin
  lbStatus.Items.Add('Event: On Extended ' + 'Extended by ' + inttostr(ExtensionLength));
  if ShareLock.Protection = ptRunCount then
    MessageDlg('Unlock Code accepted. The trial has been extended for ' + inttostr(ExtensionLength) + ' runs.', mtInformation, [mbOk], 0)
  else
    MessageDlg('Unlock Code accepted. The trial has been extended for ' + inttostr(ExtensionLength) + ' days.', mtInformation, [mbOk], 0);
end;

// User attempted to extend the trial twice

procedure TfrmTester.ShareLockTriedToExtendAgain(Sender: TObject);
begin
  lbStatus.Items.Add('Event: On tried to extend again');
  MessageDlg('You have already extended the trial period. Please contact ' + ShareLock.CompanyName + ' for a complete Unlock code.', mtError, [mbOk], 0);
  GiveOneChanceToRegister;
end;

procedure TFrmTester.GiveOneChanceToRegister;
begin
  ShareLock.Tries := 0;
  frmUnlocker.Showmodal;
  ShareLock.EnterUnlockCode(frmUnlocker.txtUnlockCode.Text, frmUnlocker.txtName.Text);
  DoStatus;
end;

procedure TfrmTester.mnuMain_Help_AboutClick(Sender: TObject);
begin
  frmAboutTester.Showmodal;
end;

procedure TfrmTester.mnuMain_Help_RegisterClick(Sender: TObject);
begin
  lbStatus.Items.Clear;
  frmUnlocker.Showmodal;
  ShareLock.EnterUnlockCode(frmUnlocker.txtUnlockCode.Text, frmUnlocker.txtName.Text);
  DoStatus;
end;

procedure TfrmTester.mnuMain_File_ExitClick(Sender: TObject);
begin
  Close;
end;

end.
